pub enum BuilderError {
Overflow,
SessionIdOverflow,
DisjointMutError,
}Variants
Overflow
Static buffer is either not long enough to hold the buffered record or length of payload part is overflowing maximum possible.
SessionIdOverflow
Session Id length is one byte but size was > 255
DisjointMutError
Error getting disjoint mut