pub struct StaticRecordBuilder<const N: usize> { /* private fields */ }Expand description
Provides statically allocated Record Builder based on worst case estimation of the maximum size of record. Typically record sizes need to be also limited based on the record limit extension but this has to be done in runtime.